pub struct PathTableAudit {
pub path_table_lbas: Vec<u32>,
pub tree_lbas: Vec<u32>,
pub phantom_lbas: Vec<u32>,
pub ghost_lbas: Vec<u32>,
}Expand description
Result of comparing the L-path table against the directory tree.
Fields
path_table_lbas: Vec<u32>tree_lbas: Vec<u32>phantom_lbas: Vec<u32>Directories in the path table but not reachable from the tree.
ghost_lbas: Vec<u32>Directories reachable from the tree but absent from the path table.